@@ -13,6 +13,7 @@ API_CONSUMPTION = "consumption"
 API_RESOURCE_ID = "resourceId"
 API_RESOURCE_NAME = "name"
 API_RESPONSE_DATA = "data"
+API_RESPONSE_LAST_TIME = "lastTs"
 API_RESPONSE_POSTAL_CODE = "postalCode"
 API_RESPONSE_QUERY = "query"
 API_RESPONSE_RATE = "rate"
@@ -22,8 +23,9 @@ API_RESPONSE_TARIFF_STRUCTURE = "structure"
 API_RESPONSE_UNIT = "units"
 
 ENDPOINT_AUTH = "auth/"
-ENDPOINT_CONSUMPTION = "readings"
+ENDPOINT_CONSUMPTION = "/readings"
 ENDPOINT_CURRENT = "current"
+ENDPOINT_LAST_DATA = "/last-time"
 ENDPOINT_RESOURCE = "resource/"
 ENDPOINT_READMETER = "meterread"
 ENDPOINT_TARIFF = "tariff"
